
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GeorgianLari(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-georgian-lari'], 'items': [{'path': {'d': 'M11.5 21a7.5 7.5 0 1 1 7.35-9'}}, {'path': {'d': 'M13 12V3'}}, {'path': {'d': 'M4 21h16'}}, {'path': {'d': 'M9 12V3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EqualApproximately(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-equal-approximately'], 'items': [{'path': {'d': 'M5 15a6.5 6.5 0 0 1 7 0 6.5 6.5 0 0 0 7 0'}}, {'path': {'d': 'M5 9a6.5 6.5 0 0 1 7 0 6.5 6.5 0 0 0 7 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Turtle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-turtle'], 'items': [{'path': {'d': 'm12 10 2 4v3a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-3a8 8 0 1 0-16 0v3a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-3l2-4h4Z'}}, {'path': {'d': 'M4.82 7.9 8 10'}}, {'path': {'d': 'M15.18 7.9 12 10'}}, {'path': {'d': 'M16.93 10H20a2 2 0 0 1 0 4H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderSync(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-sync'], 'items': [{'path': {'d': 'M9 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v.5'}}, {'path': {'d': 'M12 10v4h4'}}, {'path': {'d': 'm12 14 1.535-1.605a5 5 0 0 1 8 1.5'}}, {'path': {'d': 'M22 22v-4h-4'}}, {'path': {'d': 'm22 18-1.535 1.605a5 5 0 0 1-8-1.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Printer(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-printer'], 'items': [{'path': {'d': 'M6 18H4a2 2 0 0 1-2-2v-5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2'}}, {'path': {'d': 'M6 9V3a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v6'}}, {'rect': {'x': '6', 'y': '14', 'width': '12', 'height': '8', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessagesSquare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-messages-square'], 'items': [{'path': {'d': 'M16 10a2 2 0 0 1-2 2H6.828a2 2 0 0 0-1.414.586l-2.202 2.202A.71.71 0 0 1 2 14.286V4a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2z'}}, {'path': {'d': 'M20 9a2 2 0 0 1 2 2v10.286a.71.71 0 0 1-1.212.502l-2.202-2.202A2 2 0 0 0 17.172 19H10a2 2 0 0 1-2-2v-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CalendarX2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendar-x-2'], 'items': [{'path': {'d': 'M8 2v4'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'M21 13V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h8'}}, {'path': {'d': 'M3 10h18'}}, {'path': {'d': 'm17 22 5-5'}}, {'path': {'d': 'm17 17 5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PictureInPicture(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-picture-in-picture'], 'items': [{'path': {'d': 'M2 10h6V4'}}, {'path': {'d': 'm2 4 6 6'}}, {'path': {'d': 'M21 10V7a2 2 0 0 0-2-2h-7'}}, {'path': {'d': 'M3 14v2a2 2 0 0 0 2 2h3'}}, {'rect': {'x': '12', 'y': '14', 'width': '10', 'height': '7', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MarsStroke(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mars-stroke'], 'items': [{'path': {'d': 'm14 6 4 4'}}, {'path': {'d': 'M17 3h4v4'}}, {'path': {'d': 'm21 3-7.75 7.75'}}, {'circle': {'cx': '9', 'cy': '15', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileStack(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-stack'], 'items': [{'path': {'d': 'M11 21a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-8a1 1 0 0 1 1-1'}}, {'path': {'d': 'M16 16a1 1 0 0 1-1 1H9a1 1 0 0 1-1-1V8a1 1 0 0 1 1-1'}}, {'path': {'d': 'M21 6a2 2 0 0 0-.586-1.414l-2-2A2 2 0 0 0 17 2h-3a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserSearch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-search'], 'items': [{'circle': {'cx': '10', 'cy': '7', 'r': '4'}}, {'path': {'d': 'M10.3 15H7a4 4 0 0 0-4 4v2'}}, {'circle': {'cx': '17', 'cy': '17', 'r': '3'}}, {'path': {'d': 'm21 21-1.9-1.9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PackageMinus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-package-minus'], 'items': [{'path': {'d': 'M16 16h6'}}, {'path': {'d': 'M21 10V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l2-1.14'}}, {'path': {'d': 'm7.5 4.27 9 5.15'}}, {'polyline': {'points': '3.29 7 12 12 20.71 7'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '22', 'y2': '12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorSmartphone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-smartphone'], 'items': [{'path': {'d': 'M18 8V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h8'}}, {'path': {'d': 'M10 19v-3.96 3.15'}}, {'path': {'d': 'M7 19h5'}}, {'rect': {'width': '6', 'height': '10', 'x': '16', 'y': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PowerOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-power-off'], 'items': [{'path': {'d': 'M18.36 6.64A9 9 0 0 1 20.77 15'}}, {'path': {'d': 'M6.16 6.16a9 9 0 1 0 12.68 12.68'}}, {'path': {'d': 'M12 2v4'}}, {'path': {'d': 'm2 2 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Citrus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-citrus'], 'items': [{'path': {'d': 'M21.66 17.67a1.08 1.08 0 0 1-.04 1.6A12 12 0 0 1 4.73 2.38a1.1 1.1 0 0 1 1.61-.04z'}}, {'path': {'d': 'M19.65 15.66A8 8 0 0 1 8.35 4.34'}}, {'path': {'d': 'm14 10-5.5 5.5'}}, {'path': {'d': 'M14 17.85V10H6.15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PrinterCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-printer-check'], 'items': [{'path': {'d': 'M13.5 22H7a1 1 0 0 1-1-1v-6a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v.5'}}, {'path': {'d': 'm16 19 2 2 4-4'}}, {'path': {'d': 'M6 18H4a2 2 0 0 1-2-2v-5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v2'}}, {'path': {'d': 'M6 9V3a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Save(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-save'], 'items': [{'path': {'d': 'M15.2 3a2 2 0 0 1 1.4.6l3.8 3.8a2 2 0 0 1 .6 1.4V19a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2z'}}, {'path': {'d': 'M17 21v-7a1 1 0 0 0-1-1H8a1 1 0 0 0-1 1v7'}}, {'path': {'d': 'M7 3v4a1 1 0 0 0 1 1h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignCenterVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-center-vertical'], 'items': [{'path': {'d': 'M12 2v20'}}, {'path': {'d': 'M8 10H4a2 2 0 0 1-2-2V6c0-1.1.9-2 2-2h4'}}, {'path': {'d': 'M16 10h4a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-4'}}, {'path': {'d': 'M8 20H7a2 2 0 0 1-2-2v-2c0-1.1.9-2 2-2h1'}}, {'path': {'d': 'M16 14h1a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2h-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlaskConical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flask-conical'], 'items': [{'path': {'d': 'M14 2v6a2 2 0 0 0 .245.96l5.51 10.08A2 2 0 0 1 18 22H6a2 2 0 0 1-1.755-2.96l5.51-10.08A2 2 0 0 0 10 8V2'}}, {'path': {'d': 'M6.453 15h11.094'}}, {'path': {'d': 'M8.5 2h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MapPinHouse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-map-pin-house'], 'items': [{'path': {'d': 'M15 22a1 1 0 0 1-1-1v-4a1 1 0 0 1 .445-.832l3-2a1 1 0 0 1 1.11 0l3 2A1 1 0 0 1 22 17v4a1 1 0 0 1-1 1z'}}, {'path': {'d': 'M18 10a8 8 0 0 0-16 0c0 4.993 5.539 10.193 7.399 11.799a1 1 0 0 0 .601.2'}}, {'path': {'d': 'M18 22v-3'}}, {'circle': {'cx': '10', 'cy': '10', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Radical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-radical'], 'items': [{'path': {'d': 'M3 12h3.28a1 1 0 0 1 .948.684l2.298 7.934a.5.5 0 0 0 .96-.044L13.82 4.771A1 1 0 0 1 14.792 4H21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Headset(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-headset'], 'items': [{'path': {'d': 'M3 11h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-5Zm0 0a9 9 0 1 1 18 0m0 0v5a2 2 0 0 1-2 2h-1a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h3Z'}}, {'path': {'d': 'M21 16v2a4 4 0 0 1-4 4h-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MouseOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mouse-off'], 'items': [{'path': {'d': 'M12 6v.343'}}, {'path': {'d': 'M18.218 18.218A7 7 0 0 1 5 15V9a7 7 0 0 1 .782-3.218'}}, {'path': {'d': 'M19 13.343V9A7 7 0 0 0 8.56 2.902'}}, {'path': {'d': 'M22 22 2 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BriefcaseBusiness(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-briefcase-business'], 'items': [{'path': {'d': 'M12 12h.01'}}, {'path': {'d': 'M16 6V4a2 2 0 0 0-2-2h-4a2 2 0 0 0-2 2v2'}}, {'path': {'d': 'M22 13a18.15 18.15 0 0 1-20 0'}}, {'rect': {'width': '20', 'height': '14', 'x': '2', 'y': '6', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartPie(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-pie'], 'items': [{'path': {'d': 'M21 12c.552 0 1.005-.449.95-.998a10 10 0 0 0-8.953-8.951c-.55-.055-.998.398-.998.95v8a1 1 0 0 0 1 1z'}}, {'path': {'d': 'M21.21 15.89A10 10 0 1 1 8 2.83'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookImage(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-image'], 'items': [{'path': {'d': 'm20 13.7-2.1-2.1a2 2 0 0 0-2.8 0L9.7 17'}}, {'path': {'d': 'M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H19a1 1 0 0 1 1 1v18a1 1 0 0 1-1 1H6.5a1 1 0 0 1 0-5H20'}}, {'circle': {'cx': '10', 'cy': '8', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListRestart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-restart'], 'items': [{'path': {'d': 'M21 5H3'}}, {'path': {'d': 'M7 12H3'}}, {'path': {'d': 'M7 19H3'}}, {'path': {'d': 'M12 18a5 5 0 0 0 9-3 4.5 4.5 0 0 0-4.5-4.5c-1.33 0-2.54.54-3.41 1.41L11 14'}}, {'path': {'d': 'M11 10v4h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-lock'], 'items': [{'circle': {'cx': '10', 'cy': '7', 'r': '4'}}, {'path': {'d': 'M10.3 15H7a4 4 0 0 0-4 4v2'}}, {'path': {'d': 'M15 15.5V14a2 2 0 0 1 4 0v1.5'}}, {'rect': {'width': '8', 'height': '5', 'x': '13', 'y': '16', 'rx': '.899'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-dot'], 'items': [{'path': {'d': 'M12 17v4'}}, {'path': {'d': 'M22 12.307V15a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h8.693'}}, {'path': {'d': 'M8 21h8'}}, {'circle': {'cx': '19', 'cy': '6', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PaintbrushVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-paintbrush-vertical'], 'items': [{'path': {'d': 'M10 2v2'}}, {'path': {'d': 'M14 2v4'}}, {'path': {'d': 'M17 2a1 1 0 0 1 1 1v9H6V3a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M6 12a1 1 0 0 0-1 1v1a2 2 0 0 0 2 2h2a1 1 0 0 1 1 1v2.9a2 2 0 1 0 4 0V17a1 1 0 0 1 1-1h2a2 2 0 0 0 2-2v-1a1 1 0 0 0-1-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Glasses(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-glasses'], 'items': [{'circle': {'cx': '6', 'cy': '15', 'r': '4'}}, {'circle': {'cx': '18', 'cy': '15', 'r': '4'}}, {'path': {'d': 'M14 15a2 2 0 0 0-2-2 2 2 0 0 0-2 2'}}, {'path': {'d': 'M2.5 13 5 7c.7-1.3 1.4-2 3-2'}}, {'path': {'d': 'M21.5 13 19 7c-.7-1.3-1.5-2-3-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UsersRound(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-users-round'], 'items': [{'path': {'d': 'M18 21a8 8 0 0 0-16 0'}}, {'circle': {'cx': '10', 'cy': '8', 'r': '5'}}, {'path': {'d': 'M22 20c0-3.37-2-6.5-4-8a5 5 0 0 0-.45-8.3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WalletCards(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wallet-cards'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M3 9a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2'}}, {'path': {'d': 'M3 11h3c.8 0 1.6.3 2.1.9l1.1.9c1.6 1.6 4.1 1.6 5.7 0l1.1-.9c.5-.5 1.3-.9 2.1-.9H21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bot'], 'items': [{'path': {'d': 'M12 8V4H8'}}, {'rect': {'width': '16', 'height': '12', 'x': '4', 'y': '8', 'rx': '2'}}, {'path': {'d': 'M2 14h2'}}, {'path': {'d': 'M20 14h2'}}, {'path': {'d': 'M15 13v2'}}, {'path': {'d': 'M9 13v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Shirt(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shirt'], 'items': [{'path': {'d': 'M20.38 3.46 16 2a4 4 0 0 1-8 0L3.62 3.46a2 2 0 0 0-1.34 2.23l.58 3.47a1 1 0 0 0 .99.84H6v10c0 1.1.9 2 2 2h8a2 2 0 0 0 2-2V10h2.15a1 1 0 0 0 .99-.84l.58-3.47a2 2 0 0 0-1.34-2.23z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ImagePlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-image-plus'], 'items': [{'path': {'d': 'M16 5h6'}}, {'path': {'d': 'M19 2v6'}}, {'path': {'d': 'M21 11.5V19a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h7.5'}}, {'path': {'d': 'm21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PaintRoller(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-paint-roller'], 'items': [{'rect': {'width': '16', 'height': '6', 'x': '2', 'y': '2', 'rx': '2'}}, {'path': {'d': 'M10 16v-2a2 2 0 0 1 2-2h8a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-2'}}, {'rect': {'width': '4', 'height': '6', 'x': '8', 'y': '16', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Delete(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-delete'], 'items': [{'path': {'d': 'M10 5a2 2 0 0 0-1.344.519l-6.328 5.74a1 1 0 0 0 0 1.481l6.328 5.741A2 2 0 0 0 10 19h10a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2z'}}, {'path': {'d': 'm12 9 6 6'}}, {'path': {'d': 'm18 9-6 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareDashedTopSolid(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-dashed-top-solid'], 'items': [{'path': {'d': 'M14 21h1'}}, {'path': {'d': 'M21 14v1'}}, {'path': {'d': 'M21 19a2 2 0 0 1-2 2'}}, {'path': {'d': 'M21 9v1'}}, {'path': {'d': 'M3 14v1'}}, {'path': {'d': 'M3 5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2'}}, {'path': {'d': 'M3 9v1'}}, {'path': {'d': 'M5 21a2 2 0 0 1-2-2'}}, {'path': {'d': 'M9 21h1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquaresExclude(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-squares-exclude'], 'items': [{'path': {'d': 'M16 12v2a2 2 0 0 1-2 2H9a1 1 0 0 0-1 1v3a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V10a2 2 0 0 0-2-2h0'}}, {'path': {'d': 'M4 16a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v3a1 1 0 0 1-1 1h-5a2 2 0 0 0-2 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ToggleLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-toggle-left'], 'items': [{'circle': {'cx': '9', 'cy': '12', 'r': '3'}}, {'rect': {'width': '20', 'height': '14', 'x': '2', 'y': '5', 'rx': '7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListChecks(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-checks'], 'items': [{'path': {'d': 'M13 5h8'}}, {'path': {'d': 'M13 12h8'}}, {'path': {'d': 'M13 19h8'}}, {'path': {'d': 'm3 17 2 2 4-4'}}, {'path': {'d': 'm3 7 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pin(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pin'], 'items': [{'path': {'d': 'M12 17v5'}}, {'path': {'d': 'M9 10.76a2 2 0 0 1-1.11 1.79l-1.78.9A2 2 0 0 0 5 15.24V16a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-.76a2 2 0 0 0-1.11-1.79l-1.78-.9A2 2 0 0 1 15 10.76V7a1 1 0 0 1 1-1 2 2 0 0 0 0-4H8a2 2 0 0 0 0 4 1 1 0 0 1 1 1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Braces(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-braces'], 'items': [{'path': {'d': 'M8 3H7a2 2 0 0 0-2 2v5a2 2 0 0 1-2 2 2 2 0 0 1 2 2v5c0 1.1.9 2 2 2h1'}}, {'path': {'d': 'M16 21h1a2 2 0 0 0 2-2v-5c0-1.1.9-2 2-2a2 2 0 0 1-2-2V5a2 2 0 0 0-2-2h-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MousePointerBan(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mouse-pointer-ban'], 'items': [{'path': {'d': 'M2.034 2.681a.498.498 0 0 1 .647-.647l9 3.5a.5.5 0 0 1-.033.944L8.204 7.545a1 1 0 0 0-.66.66l-1.066 3.443a.5.5 0 0 1-.944.033z'}}, {'circle': {'cx': '16', 'cy': '16', 'r': '6'}}, {'path': {'d': 'm11.8 11.8 8.4 8.4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Refrigerator(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-refrigerator'], 'items': [{'path': {'d': 'M5 6a4 4 0 0 1 4-4h6a4 4 0 0 1 4 4v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6Z'}}, {'path': {'d': 'M5 10h14'}}, {'path': {'d': 'M15 7v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareSplitHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-split-horizontal'], 'items': [{'path': {'d': 'M8 19H5c-1 0-2-1-2-2V7c0-1 1-2 2-2h3'}}, {'path': {'d': 'M16 5h3c1 0 2 1 2 2v10c0 1-1 2-2 2h-3'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '4', 'y2': '20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Scaling(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scaling'], 'items': [{'path': {'d': 'M12 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7'}}, {'path': {'d': 'M14 15H9v-5'}}, {'path': {'d': 'M16 3h5v5'}}, {'path': {'d': 'M21 3 9 15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderKanban(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-kanban'], 'items': [{'path': {'d': 'M4 20h16a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.93a2 2 0 0 1-1.66-.9l-.82-1.2A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13c0 1.1.9 2 2 2Z'}}, {'path': {'d': 'M8 10v4'}}, {'path': {'d': 'M12 10v2'}}, {'path': {'d': 'M16 10v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BetweenVerticalStart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-between-vertical-start'], 'items': [{'rect': {'width': '7', 'height': '13', 'x': '3', 'y': '8', 'rx': '1'}}, {'path': {'d': 'm15 2-3 3-3-3'}}, {'rect': {'width': '7', 'height': '13', 'x': '14', 'y': '8', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignCenterHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-center-horizontal'], 'items': [{'path': {'d': 'M2 12h20'}}, {'path': {'d': 'M10 16v4a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-4'}}, {'path': {'d': 'M10 8V4a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v4'}}, {'path': {'d': 'M20 16v1a2 2 0 0 1-2 2h-2a2 2 0 0 1-2-2v-1'}}, {'path': {'d': 'M14 8V7c0-1.1.9-2 2-2h2a2 2 0 0 1 2 2v1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CornerDownRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-corner-down-right'], 'items': [{'path': {'d': 'm15 10 5 5-5 5'}}, {'path': {'d': 'M4 4v7a4 4 0 0 0 4 4h12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Weight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-weight'], 'items': [{'circle': {'cx': '12', 'cy': '5', 'r': '3'}}, {'path': {'d': 'M6.5 8a2 2 0 0 0-1.905 1.46L2.1 18.5A2 2 0 0 0 4 21h16a2 2 0 0 0 1.925-2.54L19.4 9.5A2 2 0 0 0 17.48 8Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Disc3(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-disc-3'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M6 12c0-1.7.7-3.2 1.8-4.2'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '2'}}, {'path': {'d': 'M18 12c0 1.7-.7 3.2-1.8 4.2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlarmSmoke(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-alarm-smoke'], 'items': [{'path': {'d': 'M11 21c0-2.5 2-2.5 2-5'}}, {'path': {'d': 'M16 21c0-2.5 2-2.5 2-5'}}, {'path': {'d': 'm19 8-.8 3a1.25 1.25 0 0 1-1.2 1H7a1.25 1.25 0 0 1-1.2-1L5 8'}}, {'path': {'d': 'M21 3a1 1 0 0 1 1 1v2a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V4a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M6 21c0-2.5 2-2.5 2-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Image(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-image'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2', 'ry': '2'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '2'}}, {'path': {'d': 'm21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Files(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-files'], 'items': [{'path': {'d': 'M15 2h-4a2 2 0 0 0-2 2v11a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8'}}, {'path': {'d': 'M16.706 2.706A2.4 2.4 0 0 0 15 2v5a1 1 0 0 0 1 1h5a2.4 2.4 0 0 0-.706-1.706z'}}, {'path': {'d': 'M5 7a2 2 0 0 0-2 2v11a2 2 0 0 0 2 2h8a2 2 0 0 0 1.732-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileMusic(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-music'], 'items': [{'path': {'d': 'M11.65 22H18a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v10.35'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M8 20v-7l3 1.474'}}, {'circle': {'cx': '6', 'cy': '20', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileCodeCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-code-corner'], 'items': [{'path': {'d': 'M4 12.15V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2h-3.35'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'm5 16-3 3 3 3'}}, {'path': {'d': 'm9 22 3-3-3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Heading2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heading-2'], 'items': [{'path': {'d': 'M4 12h8'}}, {'path': {'d': 'M4 18V6'}}, {'path': {'d': 'M12 18V6'}}, {'path': {'d': 'M21 18h-4c0-4 4-3 4-6 0-1.5-2-2.5-4-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CaseSensitive(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-case-sensitive'], 'items': [{'path': {'d': 'm2 16 4.039-9.69a.5.5 0 0 1 .923 0L11 16'}}, {'path': {'d': 'M22 9v7'}}, {'path': {'d': 'M3.304 13h6.392'}}, {'circle': {'cx': '18.5', 'cy': '12.5', 'r': '3.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessageSquareShare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-message-square-share'], 'items': [{'path': {'d': 'M12 3H4a2 2 0 0 0-2 2v16.286a.71.71 0 0 0 1.212.502l2.202-2.202A2 2 0 0 1 6.828 19H20a2 2 0 0 0 2-2v-4'}}, {'path': {'d': 'M16 3h6v6'}}, {'path': {'d': 'm16 9 6-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EggOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-egg-off'], 'items': [{'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M20 14.347V14c0-6-4-12-8-12-1.078 0-2.157.436-3.157 1.19'}}, {'path': {'d': 'M6.206 6.21C4.871 8.4 4 11.2 4 14a8 8 0 0 0 14.568 4.568'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Calendars(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendars'], 'items': [{'path': {'d': 'M12 2v2'}}, {'path': {'d': 'M15.726 21.01A2 2 0 0 1 14 22H4a2 2 0 0 1-2-2V10a2 2 0 0 1 2-2'}}, {'path': {'d': 'M18 2v2'}}, {'path': {'d': 'M2 13h2'}}, {'path': {'d': 'M8 8h14'}}, {'rect': {'x': '8', 'y': '3', 'width': '14', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Regex(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-regex'], 'items': [{'path': {'d': 'M17 3v10'}}, {'path': {'d': 'm12.67 5.5 8.66 5'}}, {'path': {'d': 'm12.67 10.5 8.66-5'}}, {'path': {'d': 'M9 17a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2v-2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CableCar(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cable-car'], 'items': [{'path': {'d': 'M10 3h.01'}}, {'path': {'d': 'M14 2h.01'}}, {'path': {'d': 'm2 9 20-5'}}, {'path': {'d': 'M12 12V6.5'}}, {'rect': {'width': '16', 'height': '10', 'x': '4', 'y': '12', 'rx': '3'}}, {'path': {'d': 'M9 12v5'}}, {'path': {'d': 'M15 12v5'}}, {'path': {'d': 'M4 17h16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RectangleVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rectangle-vertical'], 'items': [{'rect': {'width': '12', 'height': '20', 'x': '6', 'y': '2', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SwissFranc(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-swiss-franc'], 'items': [{'path': {'d': 'M10 21V3h8'}}, {'path': {'d': 'M6 16h9'}}, {'path': {'d': 'M10 9.5h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Blend(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-blend'], 'items': [{'circle': {'cx': '9', 'cy': '9', 'r': '7'}}, {'circle': {'cx': '15', 'cy': '15', 'r': '7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartNetwork(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-network'], 'items': [{'path': {'d': 'm13.11 7.664 1.78 2.672'}}, {'path': {'d': 'm14.162 12.788-3.324 1.424'}}, {'path': {'d': 'm20 4-6.06 1.515'}}, {'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'circle': {'cx': '12', 'cy': '6', 'r': '2'}}, {'circle': {'cx': '16', 'cy': '12', 'r': '2'}}, {'circle': {'cx': '9', 'cy': '15', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-lock'], 'items': [{'path': {'d': 'M4 9.8V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2h-3'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M9 17v-2a2 2 0 0 0-4 0v2'}}, {'rect': {'width': '8', 'height': '5', 'x': '3', 'y': '17', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TrendingUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-trending-up'], 'items': [{'path': {'d': 'M16 7h6v6'}}, {'path': {'d': 'm22 7-8.5 8.5-5-5L2 17'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleDollarSign(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-dollar-sign'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M16 8h-6a2 2 0 1 0 0 4h4a2 2 0 1 1 0 4H8'}}, {'path': {'d': 'M12 18V6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookOpenText(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-open-text'], 'items': [{'path': {'d': 'M12 7v14'}}, {'path': {'d': 'M16 12h2'}}, {'path': {'d': 'M16 8h2'}}, {'path': {'d': 'M3 18a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h5a4 4 0 0 1 4 4 4 4 0 0 1 4-4h5a1 1 0 0 1 1 1v13a1 1 0 0 1-1 1h-6a3 3 0 0 0-3 3 3 3 0 0 0-3-3z'}}, {'path': {'d': 'M6 12h2'}}, {'path': {'d': 'M6 8h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Anvil(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-anvil'], 'items': [{'path': {'d': 'M7 10H6a4 4 0 0 1-4-4 1 1 0 0 1 1-1h4'}}, {'path': {'d': 'M7 5a1 1 0 0 1 1-1h13a1 1 0 0 1 1 1 7 7 0 0 1-7 7H8a1 1 0 0 1-1-1z'}}, {'path': {'d': 'M9 12v5'}}, {'path': {'d': 'M15 12v5'}}, {'path': {'d': 'M5 20a3 3 0 0 1 3-3h8a3 3 0 0 1 3 3 1 1 0 0 1-1 1H6a1 1 0 0 1-1-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def NotepadTextDashed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-notepad-text-dashed'], 'items': [{'path': {'d': 'M8 2v4'}}, {'path': {'d': 'M12 2v4'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'M16 4h2a2 2 0 0 1 2 2v2'}}, {'path': {'d': 'M20 12v2'}}, {'path': {'d': 'M20 18v2a2 2 0 0 1-2 2h-1'}}, {'path': {'d': 'M13 22h-2'}}, {'path': {'d': 'M7 22H6a2 2 0 0 1-2-2v-2'}}, {'path': {'d': 'M4 14v-2'}}, {'path': {'d': 'M4 8V6a2 2 0 0 1 2-2h2'}}, {'path': {'d': 'M8 10h6'}}, {'path': {'d': 'M8 14h8'}}, {'path': {'d': 'M8 18h5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareRadical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-radical'], 'items': [{'path': {'d': 'M7 12h2l2 5 2-10h4'}}, {'rect': {'x': '3', 'y': '3', 'width': '18', 'height': '18', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Paperclip(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-paperclip'], 'items': [{'path': {'d': 'm16 6-8.414 8.586a2 2 0 0 0 2.829 2.829l8.414-8.586a4 4 0 1 0-5.657-5.657l-8.379 8.551a6 6 0 1 0 8.485 8.485l8.379-8.551'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartBarStacked(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-bar-stacked'], 'items': [{'path': {'d': 'M11 13v4'}}, {'path': {'d': 'M15 5v4'}}, {'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'rect': {'x': '7', 'y': '13', 'width': '9', 'height': '4', 'rx': '1'}}, {'rect': {'x': '7', 'y': '5', 'width': '12', 'height': '4', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Slice(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-slice'], 'items': [{'path': {'d': 'M11 16.586V19a1 1 0 0 1-1 1H2L18.37 3.63a1 1 0 1 1 3 3l-9.663 9.663a1 1 0 0 1-1.414 0L8 14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListOrdered(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-ordered'], 'items': [{'path': {'d': 'M11 5h10'}}, {'path': {'d': 'M11 12h10'}}, {'path': {'d': 'M11 19h10'}}, {'path': {'d': 'M4 4h1v5'}}, {'path': {'d': 'M4 9h2'}}, {'path': {'d': 'M6.5 20H3.4c0-1 2.6-1.925 2.6-3.5a1.5 1.5 0 0 0-2.6-1.02'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorSpeaker(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-speaker'], 'items': [{'path': {'d': 'M5.5 20H8'}}, {'path': {'d': 'M17 9h.01'}}, {'rect': {'width': '10', 'height': '16', 'x': '12', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M8 6H4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h4'}}, {'circle': {'cx': '17', 'cy': '15', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Smile(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-smile'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M8 14s1.5 2 4 2 4-2 4-2'}}, {'line': {'x1': '9', 'x2': '9.01', 'y1': '9', 'y2': '9'}}, {'line': {'x1': '15', 'x2': '15.01', 'y1': '9', 'y2': '9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextCursor(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-cursor'], 'items': [{'path': {'d': 'M17 22h-1a4 4 0 0 1-4-4V6a4 4 0 0 1 4-4h1'}}, {'path': {'d': 'M7 22h1a4 4 0 0 0 4-4v-1'}}, {'path': {'d': 'M7 2h1a4 4 0 0 1 4 4v1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def X(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-x'], 'items': [{'path': {'d': 'M18 6 6 18'}}, {'path': {'d': 'm6 6 12 12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Clock9(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clock-9'], 'items': [{'path': {'d': 'M12 6v6H8'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SlidersHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sliders-horizontal'], 'items': [{'path': {'d': 'M10 5H3'}}, {'path': {'d': 'M12 19H3'}}, {'path': {'d': 'M14 3v4'}}, {'path': {'d': 'M16 17v4'}}, {'path': {'d': 'M21 12h-9'}}, {'path': {'d': 'M21 19h-5'}}, {'path': {'d': 'M21 5h-7'}}, {'path': {'d': 'M8 10v4'}}, {'path': {'d': 'M8 12H3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareDivide(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-divide'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2', 'ry': '2'}}, {'line': {'x1': '8', 'x2': '16', 'y1': '12', 'y2': '12'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '16', 'y2': '16'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '8', 'y2': '8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LampCeiling(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp-ceiling'], 'items': [{'path': {'d': 'M12 2v5'}}, {'path': {'d': 'M14.829 15.998a3 3 0 1 1-5.658 0'}}, {'path': {'d': 'M20.92 14.606A1 1 0 0 1 20 16H4a1 1 0 0 1-.92-1.394l3-7A1 1 0 0 1 7 7h10a1 1 0 0 1 .92.606z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Diff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-diff'], 'items': [{'path': {'d': 'M12 3v14'}}, {'path': {'d': 'M5 10h14'}}, {'path': {'d': 'M5 21h14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Signpost(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-signpost'], 'items': [{'path': {'d': 'M12 13v8'}}, {'path': {'d': 'M12 3v3'}}, {'path': {'d': 'M18 6a2 2 0 0 1 1.387.56l2.307 2.22a1 1 0 0 1 0 1.44l-2.307 2.22A2 2 0 0 1 18 13H6a2 2 0 0 1-1.387-.56l-2.306-2.22a1 1 0 0 1 0-1.44l2.306-2.22A2 2 0 0 1 6 6z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ZoomIn(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-zoom-in'], 'items': [{'circle': {'cx': '11', 'cy': '11', 'r': '8'}}, {'line': {'x1': '21', 'x2': '16.65', 'y1': '21', 'y2': '16.65'}}, {'line': {'x1': '11', 'x2': '11', 'y1': '8', 'y2': '14'}}, {'line': {'x1': '8', 'x2': '14', 'y1': '11', 'y2': '11'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mouse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mouse'], 'items': [{'rect': {'x': '5', 'y': '2', 'width': '14', 'height': '20', 'rx': '7'}}, {'path': {'d': 'M12 6v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Radio(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-radio'], 'items': [{'path': {'d': 'M16.247 7.761a6 6 0 0 1 0 8.478'}}, {'path': {'d': 'M19.075 4.933a10 10 0 0 1 0 14.134'}}, {'path': {'d': 'M4.925 19.067a10 10 0 0 1 0-14.134'}}, {'path': {'d': 'M7.753 16.239a6 6 0 0 1 0-8.478'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessageCircleOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-message-circle-off'], 'items': [{'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M4.93 4.929a10 10 0 0 0-1.938 11.412 2 2 0 0 1 .094 1.167l-1.065 3.29a1 1 0 0 0 1.236 1.168l3.413-.998a2 2 0 0 1 1.099.092 10 10 0 0 0 11.302-1.989'}}, {'path': {'d': 'M8.35 2.69A10 10 0 0 1 21.3 15.65'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Banana(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-banana'], 'items': [{'path': {'d': 'M4 13c3.5-2 8-2 10 2a5.5 5.5 0 0 1 8 5'}}, {'path': {'d': 'M5.15 17.89c5.52-1.52 8.65-6.89 7-12C11.55 4 11.5 2 13 2c3.22 0 5 5.5 5 8 0 6.5-4.2 12-10.49 12C5.11 22 2 22 2 20c0-1.5 1.14-1.55 3.15-2.11Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Antenna(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-antenna'], 'items': [{'path': {'d': 'M2 12 7 2'}}, {'path': {'d': 'm7 12 5-10'}}, {'path': {'d': 'm12 12 5-10'}}, {'path': {'d': 'm17 12 5-10'}}, {'path': {'d': 'M4.5 7h15'}}, {'path': {'d': 'M12 16v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Fence(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-fence'], 'items': [{'path': {'d': 'M4 3 2 5v15c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V5Z'}}, {'path': {'d': 'M6 8h4'}}, {'path': {'d': 'M6 18h4'}}, {'path': {'d': 'm12 3-2 2v15c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V5Z'}}, {'path': {'d': 'M14 8h4'}}, {'path': {'d': 'M14 18h4'}}, {'path': {'d': 'm20 3-2 2v15c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V5Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SaudiRiyal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-saudi-riyal'], 'items': [{'path': {'d': 'm20 19.5-5.5 1.2'}}, {'path': {'d': 'M14.5 4v11.22a1 1 0 0 0 1.242.97L20 15.2'}}, {'path': {'d': 'm2.978 19.351 5.549-1.363A2 2 0 0 0 10 16V2'}}, {'path': {'d': 'M20 10 4 13.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Newspaper(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-newspaper'], 'items': [{'path': {'d': 'M15 18h-5'}}, {'path': {'d': 'M18 14h-8'}}, {'path': {'d': 'M4 22h16a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v16a2 2 0 0 1-4 0v-9a2 2 0 0 1 2-2h2'}}, {'rect': {'width': '8', 'height': '4', 'x': '10', 'y': '6', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleArrowOutUpRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-arrow-out-up-right'], 'items': [{'path': {'d': 'M22 12A10 10 0 1 1 12 2'}}, {'path': {'d': 'M22 2 12 12'}}, {'path': {'d': 'M16 2h6v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TabletSmartphone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tablet-smartphone'], 'items': [{'rect': {'width': '10', 'height': '14', 'x': '3', 'y': '8', 'rx': '2'}}, {'path': {'d': 'M5 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v16a2 2 0 0 1-2 2h-2.4'}}, {'path': {'d': 'M8 18h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hourglass(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hourglass'], 'items': [{'path': {'d': 'M5 22h14'}}, {'path': {'d': 'M5 2h14'}}, {'path': {'d': 'M17 22v-4.172a2 2 0 0 0-.586-1.414L12 12l-4.414 4.414A2 2 0 0 0 7 17.828V22'}}, {'path': {'d': 'M7 2v4.172a2 2 0 0 0 .586 1.414L12 12l4.414-4.414A2 2 0 0 0 17 6.172V2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def JapaneseYen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-japanese-yen'], 'items': [{'path': {'d': 'M12 9.5V21m0-11.5L6 3m6 6.5L18 3'}}, {'path': {'d': 'M6 15h12'}}, {'path': {'d': 'M6 11h12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def School(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-school'], 'items': [{'path': {'d': 'M14 21v-3a2 2 0 0 0-4 0v3'}}, {'path': {'d': 'M18 5v16'}}, {'path': {'d': 'm4 6 7.106-3.79a2 2 0 0 1 1.788 0L20 6'}}, {'path': {'d': 'm6 11-3.52 2.147a1 1 0 0 0-.48.854V19a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-5a1 1 0 0 0-.48-.853L18 11'}}, {'path': {'d': 'M6 5v16'}}, {'circle': {'cx': '12', 'cy': '9', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BluetoothSearching(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bluetooth-searching'], 'items': [{'path': {'d': 'm7 7 10 10-5 5V2l5 5L7 17'}}, {'path': {'d': 'M20.83 14.83a4 4 0 0 0 0-5.66'}}, {'path': {'d': 'M18 12h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SatelliteDish(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-satellite-dish'], 'items': [{'path': {'d': 'M4 10a7.31 7.31 0 0 0 10 10Z'}}, {'path': {'d': 'm9 15 3-3'}}, {'path': {'d': 'M17 13a6 6 0 0 0-6-6'}}, {'path': {'d': 'M21 13A10 10 0 0 0 11 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FunnelPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-funnel-plus'], 'items': [{'path': {'d': 'M13.354 3H3a1 1 0 0 0-.742 1.67l7.225 7.989A2 2 0 0 1 10 14v6a1 1 0 0 0 .553.895l2 1A1 1 0 0 0 14 21v-7a2 2 0 0 1 .517-1.341l1.218-1.348'}}, {'path': {'d': 'M16 6h6'}}, {'path': {'d': 'M19 3v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Underline(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-underline'], 'items': [{'path': {'d': 'M6 4v6a6 6 0 0 0 12 0V4'}}, {'line': {'x1': '4', 'x2': '20', 'y1': '20', 'y2': '20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tablets(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tablets'], 'items': [{'circle': {'cx': '7', 'cy': '7', 'r': '5'}}, {'circle': {'cx': '17', 'cy': '17', 'r': '5'}}, {'path': {'d': 'M12 17h10'}}, {'path': {'d': 'm3.46 10.54 7.08-7.08'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Waypoints(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-waypoints'], 'items': [{'circle': {'cx': '12', 'cy': '4.5', 'r': '2.5'}}, {'path': {'d': 'm10.2 6.3-3.9 3.9'}}, {'circle': {'cx': '4.5', 'cy': '12', 'r': '2.5'}}, {'path': {'d': 'M7 12h10'}}, {'circle': {'cx': '19.5', 'cy': '12', 'r': '2.5'}}, {'path': {'d': 'm13.8 17.7 3.9-3.9'}}, {'circle': {'cx': '12', 'cy': '19.5', 'r': '2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Package2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-package-2'], 'items': [{'path': {'d': 'M12 3v6'}}, {'path': {'d': 'M16.76 3a2 2 0 0 1 1.8 1.1l2.23 4.479a2 2 0 0 1 .21.891V19a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V9.472a2 2 0 0 1 .211-.894L5.45 4.1A2 2 0 0 1 7.24 3z'}}, {'path': {'d': 'M3.054 9.013h17.893'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IterationCcw(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-iteration-ccw'], 'items': [{'path': {'d': 'm16 14 4 4-4 4'}}, {'path': {'d': 'M20 10a8 8 0 1 0-8 8h8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Shuffle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shuffle'], 'items': [{'path': {'d': 'm18 14 4 4-4 4'}}, {'path': {'d': 'm18 2 4 4-4 4'}}, {'path': {'d': 'M2 18h1.973a4 4 0 0 0 3.3-1.7l5.454-8.6a4 4 0 0 1 3.3-1.7H22'}}, {'path': {'d': 'M2 6h1.972a4 4 0 0 1 3.6 2.2'}}, {'path': {'d': 'M22 18h-6.041a4 4 0 0 1-3.3-1.8l-.359-.45'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Earth(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-earth'], 'items': [{'path': {'d': 'M21.54 15H17a2 2 0 0 0-2 2v4.54'}}, {'path': {'d': 'M7 3.34V5a3 3 0 0 0 3 3a2 2 0 0 1 2 2c0 1.1.9 2 2 2a2 2 0 0 0 2-2c0-1.1.9-2 2-2h3.17'}}, {'path': {'d': 'M11 21.95V18a2 2 0 0 0-2-2a2 2 0 0 1-2-2v-1a2 2 0 0 0-2-2H2.05'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def NonBinary(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-non-binary'], 'items': [{'path': {'d': 'M12 2v10'}}, {'path': {'d': 'm8.5 4 7 4'}}, {'path': {'d': 'm8.5 8 7-4'}}, {'circle': {'cx': '12', 'cy': '17', 'r': '5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Shapes(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shapes'], 'items': [{'path': {'d': 'M8.3 10a.7.7 0 0 1-.626-1.079L11.4 3a.7.7 0 0 1 1.198-.043L16.3 8.9a.7.7 0 0 1-.572 1.1Z'}}, {'rect': {'x': '3', 'y': '14', 'width': '7', 'height': '7', 'rx': '1'}}, {'circle': {'cx': '17.5', 'cy': '17.5', 'r': '3.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PanelLeftRightDashed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-panel-left-right-dashed'], 'items': [{'path': {'d': 'M15 10V9'}}, {'path': {'d': 'M15 15v-1'}}, {'path': {'d': 'M15 21v-2'}}, {'path': {'d': 'M15 5V3'}}, {'path': {'d': 'M9 10V9'}}, {'path': {'d': 'M9 15v-1'}}, {'path': {'d': 'M9 21v-2'}}, {'path': {'d': 'M9 5V3'}}, {'rect': {'x': '3', 'y': '3', 'width': '18', 'height': '18', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HouseWifi(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-house-wifi'], 'items': [{'path': {'d': 'M9.5 13.866a4 4 0 0 1 5 .01'}}, {'path': {'d': 'M12 17h.01'}}, {'path': {'d': 'M3 10a2 2 0 0 1 .709-1.528l7-6a2 2 0 0 1 2.582 0l7 6A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z'}}, {'path': {'d': 'M7 10.754a8 8 0 0 1 10 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowsUpFromLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrows-up-from-line'], 'items': [{'path': {'d': 'm4 6 3-3 3 3'}}, {'path': {'d': 'M7 17V3'}}, {'path': {'d': 'm14 6 3-3 3 3'}}, {'path': {'d': 'M17 17V3'}}, {'path': {'d': 'M4 21h16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LockKeyholeOpen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lock-keyhole-open'], 'items': [{'circle': {'cx': '12', 'cy': '16', 'r': '1'}}, {'rect': {'width': '18', 'height': '12', 'x': '3', 'y': '10', 'rx': '2'}}, {'path': {'d': 'M7 10V7a5 5 0 0 1 9.33-2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListStart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-start'], 'items': [{'path': {'d': 'M3 5h6'}}, {'path': {'d': 'M3 12h13'}}, {'path': {'d': 'M3 19h13'}}, {'path': {'d': 'm16 8-3-3 3-3'}}, {'path': {'d': 'M21 19V7a2 2 0 0 0-2-2h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BedSingle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bed-single'], 'items': [{'path': {'d': 'M3 20v-8a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v8'}}, {'path': {'d': 'M5 10V6a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v4'}}, {'path': {'d': 'M3 18h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignVerticalDistributeStart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-vertical-distribute-start'], 'items': [{'rect': {'width': '14', 'height': '6', 'x': '5', 'y': '14', 'rx': '2'}}, {'rect': {'width': '10', 'height': '6', 'x': '7', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M2 14h20'}}, {'path': {'d': 'M2 4h20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CreativeCommons(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-creative-commons'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M10 9.3a2.8 2.8 0 0 0-3.5 1 3.1 3.1 0 0 0 0 3.4 2.7 2.7 0 0 0 3.5 1'}}, {'path': {'d': 'M17 9.3a2.8 2.8 0 0 0-3.5 1 3.1 3.1 0 0 0 0 3.4 2.7 2.7 0 0 0 3.5 1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Leaf(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-leaf'], 'items': [{'path': {'d': 'M11 20A7 7 0 0 1 9.8 6.1C15.5 5 17 4.48 19 2c1 2 2 4.18 2 8 0 5.5-4.78 10-10 10Z'}}, {'path': {'d': 'M2 21c0-3 1.85-5.36 5.08-6C9.5 14.52 12 13 13 12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Haze(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-haze'], 'items': [{'path': {'d': 'm5.2 6.2 1.4 1.4'}}, {'path': {'d': 'M2 13h2'}}, {'path': {'d': 'M20 13h2'}}, {'path': {'d': 'm17.4 7.6 1.4-1.4'}}, {'path': {'d': 'M22 17H2'}}, {'path': {'d': 'M22 21H2'}}, {'path': {'d': 'M16 13a4 4 0 0 0-8 0'}}, {'path': {'d': 'M12 5V2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Award(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-award'], 'items': [{'path': {'d': 'm15.477 12.89 1.515 8.526a.5.5 0 0 1-.81.47l-3.58-2.687a1 1 0 0 0-1.197 0l-3.586 2.686a.5.5 0 0 1-.81-.469l1.514-8.526'}}, {'circle': {'cx': '12', 'cy': '8', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MapPinXInside(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-map-pin-x-inside'], 'items': [{'path': {'d': 'M20 10c0 4.993-5.539 10.193-7.399 11.799a1 1 0 0 1-1.202 0C9.539 20.193 4 14.993 4 10a8 8 0 0 1 16 0'}}, {'path': {'d': 'm14.5 7.5-5 5'}}, {'path': {'d': 'm9.5 7.5 5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DropletOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-droplet-off'], 'items': [{'path': {'d': 'M18.715 13.186C18.29 11.858 17.384 10.607 16 9.5c-2-1.6-3.5-4-4-6.5a10.7 10.7 0 0 1-.884 2.586'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M8.795 8.797A11 11 0 0 1 8 9.5C6 11.1 5 13 5 15a7 7 0 0 0 13.222 3.208'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudLightning(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-lightning'], 'items': [{'path': {'d': 'M6 16.326A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 .5 8.973'}}, {'path': {'d': 'm13 12-3 5h4l-3 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RockingChair(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rocking-chair'], 'items': [{'polyline': {'points': '3.5 2 6.5 12.5 18 12.5'}}, {'line': {'x1': '9.5', 'x2': '5.5', 'y1': '12.5', 'y2': '20'}}, {'line': {'x1': '15', 'x2': '18.5', 'y1': '12.5', 'y2': '20'}}, {'path': {'d': 'M2.75 18a13 13 0 0 0 18.5 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListEnd(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-end'], 'items': [{'path': {'d': 'M16 5H3'}}, {'path': {'d': 'M16 12H3'}}, {'path': {'d': 'M9 19H3'}}, {'path': {'d': 'm16 16-3 3 3 3'}}, {'path': {'d': 'M21 5v12a2 2 0 0 1-2 2h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IdCardLanyard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-id-card-lanyard'], 'items': [{'path': {'d': 'M13.5 8h-3'}}, {'path': {'d': 'm15 2-1 2h3a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h3'}}, {'path': {'d': 'M16.899 22A5 5 0 0 0 7.1 22'}}, {'path': {'d': 'm9 2 3 6'}}, {'circle': {'cx': '12', 'cy': '15', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TicketSlash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ticket-slash'], 'items': [{'path': {'d': 'M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z'}}, {'path': {'d': 'm9.5 14.5 5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListChevronsUpDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-chevrons-up-down'], 'items': [{'path': {'d': 'M3 5h8'}}, {'path': {'d': 'M3 12h8'}}, {'path': {'d': 'M3 19h8'}}, {'path': {'d': 'm15 8 3-3 3 3'}}, {'path': {'d': 'm15 16 3 3 3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TimerOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-timer-off'], 'items': [{'path': {'d': 'M10 2h4'}}, {'path': {'d': 'M4.6 11a8 8 0 0 0 1.7 8.7 8 8 0 0 0 8.7 1.7'}}, {'path': {'d': 'M7.4 7.4a8 8 0 0 1 10.3 1 8 8 0 0 1 .9 10.2'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M12 12v-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mail(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mail'], 'items': [{'path': {'d': 'm22 7-8.991 5.727a2 2 0 0 1-2.009 0L2 7'}}, {'rect': {'x': '2', 'y': '4', 'width': '20', 'height': '16', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lock'], 'items': [{'rect': {'width': '18', 'height': '11', 'x': '3', 'y': '11', 'rx': '2', 'ry': '2'}}, {'path': {'d': 'M7 11V7a5 5 0 0 1 10 0v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitCompare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-compare'], 'items': [{'circle': {'cx': '18', 'cy': '18', 'r': '3'}}, {'circle': {'cx': '6', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M13 6h3a2 2 0 0 1 2 2v7'}}, {'path': {'d': 'M11 18H8a2 2 0 0 1-2-2V9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield



from tagflow import document


kebab_to_pascal = lambda s: ''.join(w.capitalize() for w in s.split('-'))


def get_icon(
        name,
        render: bool = True, 
        **kwargs):
    import lucide
    try:
        if callable(name):
            icon_class = name
        else:
            icon_class = getattr(lucide, name, None)

            if not icon_class:
                icon_class_name = kebab_to_pascal(name)
                icon_class = getattr(lucide, icon_class_name)
            
        if not render :
            return icon_class
        
        # Create an icon instance using lucide.create_icon
        with document() as doc:            
            with icon_class(**kwargs):
                pass

        # Return the SVG string
        return doc.to_html() 
    except Exception as e:
        # In case the icon name is invalid or another error occurs
        icon_name_for_error = name if isinstance(name, str) else name.__name__
        print(f"Error rendering lucide icon '{icon_name_for_error}': {e}")

        if render:
            return f'<!-- lucide icon "{icon_name_for_error}" not found -->'    
        else:
            return None




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UtilityPole(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-utility-pole'], 'items': [{'path': {'d': 'M12 2v20'}}, {'path': {'d': 'M2 5h20'}}, {'path': {'d': 'M3 3v2'}}, {'path': {'d': 'M7 3v2'}}, {'path': {'d': 'M17 3v2'}}, {'path': {'d': 'M21 3v2'}}, {'path': {'d': 'm19 5-7 7-7-7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wallet(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wallet'], 'items': [{'path': {'d': 'M19 7V4a1 1 0 0 0-1-1H5a2 2 0 0 0 0 4h15a1 1 0 0 1 1 1v4h-3a2 2 0 0 0 0 4h3a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1'}}, {'path': {'d': 'M3 5v14a2 2 0 0 0 2 2h15a1 1 0 0 0 1-1v-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ShoppingBasket(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shopping-basket'], 'items': [{'path': {'d': 'm15 11-1 9'}}, {'path': {'d': 'm19 11-4-7'}}, {'path': {'d': 'M2 11h20'}}, {'path': {'d': 'm3.5 11 1.6 7.4a2 2 0 0 0 2 1.6h9.8a2 2 0 0 0 2-1.6l1.7-7.4'}}, {'path': {'d': 'M4.5 15.5h15'}}, {'path': {'d': 'm5 11 4-7'}}, {'path': {'d': 'm9 11 1 9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Vibrate(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-vibrate'], 'items': [{'path': {'d': 'm2 8 2 2-2 2 2 2-2 2'}}, {'path': {'d': 'm22 8-2 2 2 2-2 2 2 2'}}, {'rect': {'width': '8', 'height': '14', 'x': '8', 'y': '5', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareUserRound(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-user-round'], 'items': [{'path': {'d': 'M18 21a6 6 0 0 0-12 0'}}, {'circle': {'cx': '12', 'cy': '11', 'r': '4'}}, {'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BringToFront(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bring-to-front'], 'items': [{'rect': {'x': '8', 'y': '8', 'width': '8', 'height': '8', 'rx': '2'}}, {'path': {'d': 'M4 10a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2'}}, {'path': {'d': 'M14 20a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareSquare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-square'], 'items': [{'rect': {'x': '3', 'y': '3', 'width': '18', 'height': '18', 'rx': '2'}}, {'rect': {'x': '8', 'y': '8', 'width': '8', 'height': '8', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MapPinCheckInside(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-map-pin-check-inside'], 'items': [{'path': {'d': 'M20 10c0 4.993-5.539 10.193-7.399 11.799a1 1 0 0 1-1.202 0C9.539 20.193 4 14.993 4 10a8 8 0 0 1 16 0'}}, {'path': {'d': 'm9 10 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CakeSlice(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cake-slice'], 'items': [{'path': {'d': 'M16 13H3'}}, {'path': {'d': 'M16 17H3'}}, {'path': {'d': 'm7.2 7.9-3.388 2.5A2 2 0 0 0 3 12.01V20a1 1 0 0 0 1 1h16a1 1 0 0 0 1-1v-8.654c0-2-2.44-6.026-6.44-8.026a1 1 0 0 0-1.082.057L10.4 5.6'}}, {'circle': {'cx': '9', 'cy': '7', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Spool(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-spool'], 'items': [{'path': {'d': 'M17 13.44 4.442 17.082A2 2 0 0 0 4.982 21H19a2 2 0 0 0 .558-3.921l-1.115-.32A2 2 0 0 1 17 14.837V7.66'}}, {'path': {'d': 'm7 10.56 12.558-3.642A2 2 0 0 0 19.018 3H5a2 2 0 0 0-.558 3.921l1.115.32A2 2 0 0 1 7 9.163v7.178'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderHeart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-heart'], 'items': [{'path': {'d': 'M10.638 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v3.417'}}, {'path': {'d': 'M14.62 18.8A2.25 2.25 0 1 1 18 15.836a2.25 2.25 0 1 1 3.38 2.966l-2.626 2.856a.998.998 0 0 1-1.507 0z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Ligature(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ligature'], 'items': [{'path': {'d': 'M14 12h2v8'}}, {'path': {'d': 'M14 20h4'}}, {'path': {'d': 'M6 12h4'}}, {'path': {'d': 'M6 20h4'}}, {'path': {'d': 'M8 20V8a4 4 0 0 1 7.464-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PlugZap(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-plug-zap'], 'items': [{'path': {'d': 'M6.3 20.3a2.4 2.4 0 0 0 3.4 0L12 18l-6-6-2.3 2.3a2.4 2.4 0 0 0 0 3.4Z'}}, {'path': {'d': 'm2 22 3-3'}}, {'path': {'d': 'M7.5 13.5 10 11'}}, {'path': {'d': 'M10.5 16.5 13 14'}}, {'path': {'d': 'm18 3-4 4h6l-4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pill(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pill'], 'items': [{'path': {'d': 'm10.5 20.5 10-10a4.95 4.95 0 1 0-7-7l-10 10a4.95 4.95 0 1 0 7 7Z'}}, {'path': {'d': 'm8.5 8.5 7 7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CalendarFold(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendar-fold'], 'items': [{'path': {'d': 'M3 20a2 2 0 0 0 2 2h10a2.4 2.4 0 0 0 1.706-.706l3.588-3.588A2.4 2.4 0 0 0 21 16V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2z'}}, {'path': {'d': 'M15 22v-5a1 1 0 0 1 1-1h5'}}, {'path': {'d': 'M8 2v4'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'M3 10h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquaresUnite(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-squares-unite'], 'items': [{'path': {'d': 'M4 16a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v3a1 1 0 0 0 1 1h3a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H10a2 2 0 0 1-2-2v-3a1 1 0 0 0-1-1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudMoon(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-moon'], 'items': [{'path': {'d': 'M13 16a3 3 0 0 1 0 6H7a5 5 0 1 1 4.9-6z'}}, {'path': {'d': 'M18.376 14.512a6 6 0 0 0 3.461-4.127c.148-.625-.659-.97-1.248-.714a4 4 0 0 1-5.259-5.26c.255-.589-.09-1.395-.716-1.248a6 6 0 0 0-4.594 5.36'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WashingMachine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-washing-machine'], 'items': [{'path': {'d': 'M3 6h3'}}, {'path': {'d': 'M17 6h.01'}}, {'rect': {'width': '18', 'height': '20', 'x': '3', 'y': '2', 'rx': '2'}}, {'circle': {'cx': '12', 'cy': '13', 'r': '5'}}, {'path': {'d': 'M12 18a2.5 2.5 0 0 0 0-5 2.5 2.5 0 0 1 0-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TreeDeciduous(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tree-deciduous'], 'items': [{'path': {'d': 'M8 19a4 4 0 0 1-2.24-7.32A3.5 3.5 0 0 1 9 6.03V6a3 3 0 1 1 6 0v.04a3.5 3.5 0 0 1 3.24 5.65A4 4 0 0 1 16 19Z'}}, {'path': {'d': 'M12 19v3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareArrowOutDownLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-arrow-out-down-left'], 'items': [{'path': {'d': 'M13 21h6a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v6'}}, {'path': {'d': 'm3 21 9-9'}}, {'path': {'d': 'M9 21H3v-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CheckCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-check-check'], 'items': [{'path': {'d': 'M18 6 7 17l-5-5'}}, {'path': {'d': 'm22 10-7.5 7.5L13 16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDownLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-left'], 'items': [{'path': {'d': 'M17 7 7 17'}}, {'path': {'d': 'M17 17H7V7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LaptopMinimalCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-laptop-minimal-check'], 'items': [{'path': {'d': 'M2 20h20'}}, {'path': {'d': 'm9 10 2 2 4-4'}}, {'rect': {'x': '3', 'y': '4', 'width': '18', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SignalMedium(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-signal-medium'], 'items': [{'path': {'d': 'M2 20h.01'}}, {'path': {'d': 'M7 20v-4'}}, {'path': {'d': 'M12 20v-8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EarthLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-earth-lock'], 'items': [{'path': {'d': 'M7 3.34V5a3 3 0 0 0 3 3'}}, {'path': {'d': 'M11 21.95V18a2 2 0 0 0-2-2 2 2 0 0 1-2-2v-1a2 2 0 0 0-2-2H2.05'}}, {'path': {'d': 'M21.54 15H17a2 2 0 0 0-2 2v4.54'}}, {'path': {'d': 'M12 2a10 10 0 1 0 9.54 13'}}, {'path': {'d': 'M20 6V4a2 2 0 1 0-4 0v2'}}, {'rect': {'width': '8', 'height': '5', 'x': '14', 'y': '6', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Luggage(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-luggage'], 'items': [{'path': {'d': 'M6 20a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2'}}, {'path': {'d': 'M8 18V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v14'}}, {'path': {'d': 'M10 20h4'}}, {'circle': {'cx': '16', 'cy': '20', 'r': '2'}}, {'circle': {'cx': '8', 'cy': '20', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tent(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tent'], 'items': [{'path': {'d': 'M3.5 21 14 3'}}, {'path': {'d': 'M20.5 21 10 3'}}, {'path': {'d': 'M15.5 21 12 15l-3.5 6'}}, {'path': {'d': 'M2 21h20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ExternalLink(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-external-link'], 'items': [{'path': {'d': 'M15 3h6v6'}}, {'path': {'d': 'M10 14 21 3'}}, {'path': {'d': 'M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Gem(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-gem'], 'items': [{'path': {'d': 'M10.5 3 8 9l4 13 4-13-2.5-6'}}, {'path': {'d': 'M17 3a2 2 0 0 1 1.6.8l3 4a2 2 0 0 1 .013 2.382l-7.99 10.986a2 2 0 0 1-3.247 0l-7.99-10.986A2 2 0 0 1 2.4 7.8l2.998-3.997A2 2 0 0 1 7 3z'}}, {'path': {'d': 'M2 9h20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Share2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-share-2'], 'items': [{'circle': {'cx': '18', 'cy': '5', 'r': '3'}}, {'circle': {'cx': '6', 'cy': '12', 'r': '3'}}, {'circle': {'cx': '18', 'cy': '19', 'r': '3'}}, {'line': {'x1': '8.59', 'x2': '15.42', 'y1': '13.51', 'y2': '17.49'}}, {'line': {'x1': '15.41', 'x2': '8.59', 'y1': '6.51', 'y2': '10.49'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Watch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-watch'], 'items': [{'path': {'d': 'M12 10v2.2l1.6 1'}}, {'path': {'d': 'm16.13 7.66-.81-4.05a2 2 0 0 0-2-1.61h-2.68a2 2 0 0 0-2 1.61l-.78 4.05'}}, {'path': {'d': 'm7.88 16.36.8 4a2 2 0 0 0 2 1.61h2.72a2 2 0 0 0 2-1.61l.81-4.05'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClockCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clock-check'], 'items': [{'path': {'d': 'M12 6v6l4 2'}}, {'path': {'d': 'M22 12a10 10 0 1 0-11 9.95'}}, {'path': {'d': 'm22 16-5.5 5.5L14 19'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitGraph(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-graph'], 'items': [{'circle': {'cx': '5', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M5 9v6'}}, {'circle': {'cx': '5', 'cy': '18', 'r': '3'}}, {'path': {'d': 'M12 3v18'}}, {'circle': {'cx': '19', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M16 15.7A9 9 0 0 0 19 9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Trash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-trash'], 'items': [{'path': {'d': 'M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6'}}, {'path': {'d': 'M3 6h18'}}, {'path': {'d': 'M8 6V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LampWallUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp-wall-up'], 'items': [{'path': {'d': 'M19.929 9.629A1 1 0 0 1 19 11H9a1 1 0 0 1-.928-1.371l2-5A1 1 0 0 1 11 4h6a1 1 0 0 1 .928.629z'}}, {'path': {'d': 'M6 15a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H5a1 1 0 0 1-1-1v-4a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M8 18h4a2 2 0 0 0 2-2v-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Divide(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-divide'], 'items': [{'circle': {'cx': '12', 'cy': '6', 'r': '1'}}, {'line': {'x1': '5', 'x2': '19', 'y1': '12', 'y2': '12'}}, {'circle': {'cx': '12', 'cy': '18', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pyramid(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pyramid'], 'items': [{'path': {'d': 'M2.5 16.88a1 1 0 0 1-.32-1.43l9-13.02a1 1 0 0 1 1.64 0l9 13.01a1 1 0 0 1-.32 1.44l-8.51 4.86a2 2 0 0 1-1.98 0Z'}}, {'path': {'d': 'M12 2v20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GraduationCap(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-graduation-cap'], 'items': [{'path': {'d': 'M21.42 10.922a1 1 0 0 0-.019-1.838L12.83 5.18a2 2 0 0 0-1.66 0L2.6 9.08a1 1 0 0 0 0 1.832l8.57 3.908a2 2 0 0 0 1.66 0z'}}, {'path': {'d': 'M22 10v6'}}, {'path': {'d': 'M6 12.5V16a6 3 0 0 0 12 0v-3.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlipVertical2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flip-vertical-2'], 'items': [{'path': {'d': 'm17 3-5 5-5-5h10'}}, {'path': {'d': 'm17 21-5-5-5 5h10'}}, {'path': {'d': 'M4 12H2'}}, {'path': {'d': 'M10 12H8'}}, {'path': {'d': 'M16 12h-2'}}, {'path': {'d': 'M22 12h-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlagOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flag-off'], 'items': [{'path': {'d': 'M16 16c-3 0-5-2-8-2a6 6 0 0 0-4 1.528'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M4 22V4'}}, {'path': {'d': 'M7.656 2H8c3 0 5 2 7.333 2q2 0 3.067-.8A1 1 0 0 1 20 4v10.347'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Asterisk(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-asterisk'], 'items': [{'path': {'d': 'M12 6v12'}}, {'path': {'d': 'M17.196 9 6.804 15'}}, {'path': {'d': 'm6.804 9 10.392 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareParkingOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-parking-off'], 'items': [{'path': {'d': 'M3.6 3.6A2 2 0 0 1 5 3h14a2 2 0 0 1 2 2v14a2 2 0 0 1-.59 1.41'}}, {'path': {'d': 'M3 8.7V19a2 2 0 0 0 2 2h10.3'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M13 13a3 3 0 1 0 0-6H9v2'}}, {'path': {'d': 'M9 17v-2.3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDownUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-up'], 'items': [{'path': {'d': 'm3 16 4 4 4-4'}}, {'path': {'d': 'M7 20V4'}}, {'path': {'d': 'm21 8-4-4-4 4'}}, {'path': {'d': 'M17 4v16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Speaker(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-speaker'], 'items': [{'rect': {'width': '16', 'height': '20', 'x': '4', 'y': '2', 'rx': '2'}}, {'path': {'d': 'M12 6h.01'}}, {'circle': {'cx': '12', 'cy': '14', 'r': '4'}}, {'path': {'d': 'M12 14h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Palette(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-palette'], 'items': [{'path': {'d': 'M12 22a1 1 0 0 1 0-20 10 9 0 0 1 10 9 5 5 0 0 1-5 5h-2.25a1.75 1.75 0 0 0-1.4 2.8l.3.4a1.75 1.75 0 0 1-1.4 2.8z'}}, {'circle': {'cx': '13.5', 'cy': '6.5', 'r': '.5', 'fill': 'currentColor'}}, {'circle': {'cx': '17.5', 'cy': '10.5', 'r': '.5', 'fill': 'currentColor'}}, {'circle': {'cx': '6.5', 'cy': '12.5', 'r': '.5', 'fill': 'currentColor'}}, {'circle': {'cx': '8.5', 'cy': '7.5', 'r': '.5', 'fill': 'currentColor'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-off'], 'items': [{'path': {'d': 'M17 17H4a2 2 0 0 1-2-2V5c0-1.5 1-2 1-2'}}, {'path': {'d': 'M22 15V5a2 2 0 0 0-2-2H9'}}, {'path': {'d': 'M8 21h8'}}, {'path': {'d': 'M12 17v4'}}, {'path': {'d': 'm2 2 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CigaretteOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cigarette-off'], 'items': [{'path': {'d': 'M12 12H3a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h13'}}, {'path': {'d': 'M18 8c0-2.5-2-2.5-2-5'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M21 12a1 1 0 0 1 1 1v2a1 1 0 0 1-.5.866'}}, {'path': {'d': 'M22 8c0-2.5-2-2.5-2-5'}}, {'path': {'d': 'M7 12v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Fuel(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-fuel'], 'items': [{'path': {'d': 'M14 13h2a2 2 0 0 1 2 2v2a2 2 0 0 0 4 0v-6.998a2 2 0 0 0-.59-1.42L18 5'}}, {'path': {'d': 'M14 21V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v16'}}, {'path': {'d': 'M2 21h13'}}, {'path': {'d': 'M3 9h11'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FastForward(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-fast-forward'], 'items': [{'path': {'d': 'M12 6a2 2 0 0 1 3.414-1.414l6 6a2 2 0 0 1 0 2.828l-6 6A2 2 0 0 1 12 18z'}}, {'path': {'d': 'M2 6a2 2 0 0 1 3.414-1.414l6 6a2 2 0 0 1 0 2.828l-6 6A2 2 0 0 1 2 18z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Redo(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-redo'], 'items': [{'path': {'d': 'M21 7v6h-6'}}, {'path': {'d': 'M3 17a9 9 0 0 1 9-9 9 9 0 0 1 6 2.3l3 2.7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudAlert(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-alert'], 'items': [{'path': {'d': 'M12 12v4'}}, {'path': {'d': 'M12 20h.01'}}, {'path': {'d': 'M17 18h.5a1 1 0 0 0 0-9h-1.79A7 7 0 1 0 7 17.708'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowBigLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-big-left'], 'items': [{'path': {'d': 'M13 9a1 1 0 0 1-1-1V5.061a1 1 0 0 0-1.811-.75l-6.835 6.836a1.207 1.207 0 0 0 0 1.707l6.835 6.835a1 1 0 0 0 1.811-.75V16a1 1 0 0 1 1-1h6a1 1 0 0 0 1-1v-4a1 1 0 0 0-1-1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserRoundPen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-round-pen'], 'items': [{'path': {'d': 'M2 21a8 8 0 0 1 10.821-7.487'}}, {'path': {'d': 'M21.378 16.626a1 1 0 0 0-3.004-3.004l-4.01 4.012a2 2 0 0 0-.506.854l-.837 2.87a.5.5 0 0 0 .62.62l2.87-.837a2 2 0 0 0 .854-.506z'}}, {'circle': {'cx': '10', 'cy': '8', 'r': '5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TramFront(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tram-front'], 'items': [{'rect': {'width': '16', 'height': '16', 'x': '4', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M4 11h16'}}, {'path': {'d': 'M12 3v8'}}, {'path': {'d': 'm8 19-2 3'}}, {'path': {'d': 'm18 22-2-3'}}, {'path': {'d': 'M8 15h.01'}}, {'path': {'d': 'M16 15h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Triangle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-triangle'], 'items': [{'path': {'d': 'M13.73 4a2 2 0 0 0-3.46 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoonStar(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-moon-star'], 'items': [{'path': {'d': 'M18 5h4'}}, {'path': {'d': 'M20 3v4'}}, {'path': {'d': 'M20.985 12.486a9 9 0 1 1-9.473-9.472c.405-.022.617.46.402.803a6 6 0 0 0 8.268 8.268c.344-.215.825-.004.803.401'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bike(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bike'], 'items': [{'circle': {'cx': '18.5', 'cy': '17.5', 'r': '3.5'}}, {'circle': {'cx': '5.5', 'cy': '17.5', 'r': '3.5'}}, {'circle': {'cx': '15', 'cy': '5', 'r': '1'}}, {'path': {'d': 'M12 17.5V14l-3-3 4-3 2 3h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListVideo(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-video'], 'items': [{'path': {'d': 'M21 5H3'}}, {'path': {'d': 'M10 12H3'}}, {'path': {'d': 'M10 19H3'}}, {'path': {'d': 'M15 12.003a1 1 0 0 1 1.517-.859l4.997 2.997a1 1 0 0 1 0 1.718l-4.997 2.997a1 1 0 0 1-1.517-.86z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleAlert(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-alert'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '8', 'y2': '12'}}, {'line': {'x1': '12', 'x2': '12.01', 'y1': '16', 'y2': '16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Cable(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cable'], 'items': [{'path': {'d': 'M17 19a1 1 0 0 1-1-1v-2a2 2 0 0 1 2-2h2a2 2 0 0 1 2 2v2a1 1 0 0 1-1 1z'}}, {'path': {'d': 'M17 21v-2'}}, {'path': {'d': 'M19 14V6.5a1 1 0 0 0-7 0v11a1 1 0 0 1-7 0V10'}}, {'path': {'d': 'M21 21v-2'}}, {'path': {'d': 'M3 5V3'}}, {'path': {'d': 'M4 10a2 2 0 0 1-2-2V6a1 1 0 0 1 1-1h4a1 1 0 0 1 1 1v2a2 2 0 0 1-2 2z'}}, {'path': {'d': 'M7 5V3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Undo2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-undo-2'], 'items': [{'path': {'d': 'M9 14 4 9l5-5'}}, {'path': {'d': 'M4 9h10.5a5.5 5.5 0 0 1 5.5 5.5a5.5 5.5 0 0 1-5.5 5.5H11'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileBracesCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-braces-corner'], 'items': [{'path': {'d': 'M14 22h4a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v6'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M5 14a1 1 0 0 0-1 1v2a1 1 0 0 1-1 1 1 1 0 0 1 1 1v2a1 1 0 0 0 1 1'}}, {'path': {'d': 'M9 22a1 1 0 0 0 1-1v-2a1 1 0 0 1 1-1 1 1 0 0 1-1-1v-2a1 1 0 0 0-1-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListIndentDecrease(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-indent-decrease'], 'items': [{'path': {'d': 'M21 5H11'}}, {'path': {'d': 'M21 12H11'}}, {'path': {'d': 'M21 19H11'}}, {'path': {'d': 'm7 8-4 4 4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Squircle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-squircle'], 'items': [{'path': {'d': 'M12 3c7.2 0 9 1.8 9 9s-1.8 9-9 9-9-1.8-9-9 1.8-9 9-9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Dribbble(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-dribbble'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M19.13 5.09C15.22 9.14 10 10.44 2.25 10.94'}}, {'path': {'d': 'M21.75 12.84c-6.62-1.41-12.14 1-16.38 6.32'}}, {'path': {'d': 'M8.56 2.75c4.37 6 6 9.42 8 17.72'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IdCard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-id-card'], 'items': [{'path': {'d': 'M16 10h2'}}, {'path': {'d': 'M16 14h2'}}, {'path': {'d': 'M6.17 15a3 3 0 0 1 5.66 0'}}, {'circle': {'cx': '9', 'cy': '11', 'r': '2'}}, {'rect': {'x': '2', 'y': '5', 'width': '20', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MousePointerClick(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mouse-pointer-click'], 'items': [{'path': {'d': 'M14 4.1 12 6'}}, {'path': {'d': 'm5.1 8-2.9-.8'}}, {'path': {'d': 'm6 12-1.9 2'}}, {'path': {'d': 'M7.2 2.2 8 5.1'}}, {'path': {'d': 'M9.037 9.69a.498.498 0 0 1 .653-.653l11 4.5a.5.5 0 0 1-.074.949l-4.349 1.041a1 1 0 0 0-.74.739l-1.04 4.35a.5.5 0 0 1-.95.074z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Package(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-package'], 'items': [{'path': {'d': 'M11 21.73a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73z'}}, {'path': {'d': 'M12 22V12'}}, {'polyline': {'points': '3.29 7 12 12 20.71 7'}}, {'path': {'d': 'm7.5 4.27 9 5.15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CirclePlay(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-play'], 'items': [{'path': {'d': 'M9 9.003a1 1 0 0 1 1.517-.859l4.997 2.997a1 1 0 0 1 0 1.718l-4.997 2.997A1 1 0 0 1 9 14.996z'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChevronsUpDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chevrons-up-down'], 'items': [{'path': {'d': 'm7 15 5 5 5-5'}}, {'path': {'d': 'm7 9 5-5 5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserRoundSearch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-round-search'], 'items': [{'circle': {'cx': '10', 'cy': '8', 'r': '5'}}, {'path': {'d': 'M2 21a8 8 0 0 1 10.434-7.62'}}, {'circle': {'cx': '18', 'cy': '18', 'r': '3'}}, {'path': {'d': 'm22 22-1.9-1.9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitPullRequestArrow(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-pull-request-arrow'], 'items': [{'circle': {'cx': '5', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M5 9v12'}}, {'circle': {'cx': '19', 'cy': '18', 'r': '3'}}, {'path': {'d': 'm15 9-3-3 3-3'}}, {'path': {'d': 'M12 6h5a2 2 0 0 1 2 2v7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Coffee(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-coffee'], 'items': [{'path': {'d': 'M10 2v2'}}, {'path': {'d': 'M14 2v2'}}, {'path': {'d': 'M16 8a1 1 0 0 1 1 1v8a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4V9a1 1 0 0 1 1-1h14a4 4 0 1 1 0 8h-1'}}, {'path': {'d': 'M6 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudDownload(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-download'], 'items': [{'path': {'d': 'M12 13v8l-4-4'}}, {'path': {'d': 'm12 21 4-4'}}, {'path': {'d': 'M4.393 15.269A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.436 8.284'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BluetoothConnected(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bluetooth-connected'], 'items': [{'path': {'d': 'm7 7 10 10-5 5V2l5 5L7 17'}}, {'line': {'x1': '18', 'x2': '21', 'y1': '12', 'y2': '12'}}, {'line': {'x1': '3', 'x2': '6', 'y1': '12', 'y2': '12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Transgender(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-transgender'], 'items': [{'path': {'d': 'M12 16v6'}}, {'path': {'d': 'M14 20h-4'}}, {'path': {'d': 'M18 2h4v4'}}, {'path': {'d': 'm2 2 7.17 7.17'}}, {'path': {'d': 'M2 5.355V2h3.357'}}, {'path': {'d': 'm22 2-7.17 7.17'}}, {'path': {'d': 'M8 5 5 8'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChevronsRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chevrons-right'], 'items': [{'path': {'d': 'm6 17 5-5-5-5'}}, {'path': {'d': 'm13 17 5-5-5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CheckLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-check-line'], 'items': [{'path': {'d': 'M20 4L9 15'}}, {'path': {'d': 'M21 19L3 19'}}, {'path': {'d': 'M9 15L4 10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RefreshCcwDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-refresh-ccw-dot'], 'items': [{'path': {'d': 'M21 12a9 9 0 0 0-9-9 9.75 9.75 0 0 0-6.74 2.74L3 8'}}, {'path': {'d': 'M3 3v5h5'}}, {'path': {'d': 'M3 12a9 9 0 0 0 9 9 9.75 9.75 0 0 0 6.74-2.74L21 16'}}, {'path': {'d': 'M16 16h5v5'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
